Email class
Constructors
-
Email({required MailAddress sender, required String subject, required String message, required List<
MailAddress> to, required List<MailAddress> cc, required List<MailAddress> bcc, MailAddress? replyTo}) -
const
Properties
-
bcc
→ List<
MailAddress> -
final
-
cc
→ List<
MailAddress> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- replyTo → MailAddress?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → MailAddress
-
final
- subject → String
-
final
-
to
→ List<
MailAddress> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited