MessageManager class
Constructors
-
MessageManager({required List<
Observer> observers, required AuthManager auth})
Properties
- auth → AuthManager
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
observers
→ List<
Observer> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeData(
SecureSocket socket, Email email) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited